;
; Outlaw v1.0
; David Phillips <electrum@tfs.net>
; Started:     11/17/98
; Last Update: 11/18/98
;
;
; This is just another demo of game programming concepts.  This is supposed
; to be a simple version of Outlaw, which was a game for the Atari 2600.
; Yes, I still have an Atari 2600, and it works!  I decided to write this
; after I saw Dan's (brncavfan2@aol.com) War86.  He mentioned Link Play as
; a future feature.  I was going just add link play to his game for fun, but
; he didn't include the source.  So I decided to rewrite it from scratch...
;
; The link routines are essentially the link routines from Jimmy Mardell's
; ZTetris, modified to work by themselves and with interrupts off (in other
; words they use port 1 to check for the break key).  The ZTetris routines
; are in turn Pascal Bouron's link routines with an added break routine and
; some other code for ZTetris (that I took out...it was in the way, hehe).
;
; I have (once again) used the ASCR routines in this program, simply because
; I like them and happened to be what I grabbed first from my ever growing
; asm directory.  Jimmy Mardell is a great guy, you have to thank him for these
; wonderful routines from his awsome game, Sqrxz.  I only used PutSprite, as
; I had no need to save the background.  The clipping is nice and makes it a
; little easier to do the bullets and the guys with the same sprite routine.
;
; A double buffer or virtual screen is used for a few reasons.  The first (and
; probably most important) is that I'm lazy.  Using a virtual screen allows
; for flicker-free graphics without worring about erasing/moving/redrawing
; in a timely fashion.  With a virtual screen, you can erase your sprites
; at the top of the loop, move them in the middle and redraw them right
; before you copy the virtual screen and there won't be any flicker.  I like
; to use them, I've always used them when doing anything on the PC, so why
; not use it here?  The disadvantage of a virtual screen is that you can't 
; use any of the normal text printing routines (at least not without alot of
; work...have to print AFTER you dump the virtual screen) because the text
; will be written to video memory and then immediately overwritten when the
; virtual screen is displayed.  So the alternative is to set the textwrite flag
; of the new_grf_flgs and use only small text, which will be drawn to the
; virtual screen (assuming that _plotSScreen is used, which is what it's there
; for).
;
; If you're new to game programming for the calculator, there's probably alot you
; can learn from this code.  It's short, commented and shows many important
; concepts about game coding.  If you see something that you think could be done
; better, it probably can.  It only took me 2 evenings to write this.  ;-)
;

#include "ti86asm.inc"
#include "asm86.h"

.org _asm_exec_ram

clipmask  		= _textShadow		; [1] ASCR byte
rows2put  		= _textShadow + 1	; [1] ASCR byte
bitmask  		= _textShadow + 2	; [1] ASCR byte

Player1L		= _textShadow + 3	; [1] Player 1's location
Player2L		= _textShadow + 4	; [1] Player 2's location

Player1Shot		= _textShadow + 5	; [2] Player 1's bullet ($80 = inactive)
Player2Shot 	= _textShadow + 7	; [2] Player 2's bullet

Player1Score	= _textShadow + 9	; [1] Player 1's score
Player2Score	= _textShadow + 10	; [1] Player 2's score

OurNum			= _textShadow + 11	; [1] which player we are (0 = 1, 1 = 2)
FrameByte		= _textShadow + 12	; [1] what to send at end of frame
									; 	  (0 = nothing, 1 = move up, 2 = move down, 3 = fire, 4 = quit)

VirtScr			= _plotSScreen		; [1024] the virtual screen



ProgramHeader:
 nop								; for the title line in shells (ASE, Rascall)

 jp Start  							; jump to real start of program

 .dw $0000							; used by shell
 .dw ShellTitle						; pointer to title of the program
ShellTitle:
 .db "Outlaw v1.0 by David P",0		; text in the shell title

Start:
 call _flushallmenus				; close any open menus
 call _runindicoff					; turn off the run indicator
 res appTextSave,(iy+appflags)		; don't write to text shadow

ShowTitlePic:
 ld hl,TitlePic						; show the cool title picture
 ld de,$fc00						; display to video memory
 call DispRLE						; our tiny RLE decompressor (it's only 32 bytes!)
TitleL:
 call _getky						; check for keypresses
 or a								; has a key been pressed?
 jr z,TitleL						; wait for a key to be hit

Menu:
 res textwrite,(iy+new_grf_flgs)	; print text to video ram
 ld hl,MenuTable					; point to the menu table
 jp DoMenu							; our nifty menu routine (notice it's a JP!)

Quit:
 set appTextSave,(iy+appflags)		; want to clear text shadow
 call _clrScrn						; clear the screen and text shadow
 call _homeup						; cursor to upper-left corner
 ret								; RETurn to the TI-OS or a shell

ShowHelp:
 ld hl,HelpText						; point to help text
 call TextView						; our cool text viewer (gotta love it!)
 jr Menu							; go back to the menu


StartGame:
 call ReceiveByte		; see if they are sending

 or a					; is it 0?

 jr nz,NoWait	        ; If byte gotten, the other calc was waiting

 call _clrLCD			; clear screen
 call _homeup			; cursor to upper-left
 ld hl,WaitingText		; point to "waiting..."
 call _puts				; display it 
 ld a,1					; send a non-zero byte

 call SendByte	       	; Else wait until the other calc responds
 xor a					; we are player 1
 ld (OurNum),a			; set who we are
 jr PlayGame			; actually start playing
NoWait:
 ld a,1					; we are player 2
 ld (OurNum),a			; set who we are [fall through]

PlayGame:
 call _clrLCD			; clear screen
 ld hl,VirtScr			; point to virtual screen
 ld de,VirtScr+1		; point to second byte of virtual screen
 ld (hl),0				; set the first byte to 0
 ld bc,1023				; need to clear out all 1024 bytes (first is clear now)
 ldir					; clear by copying first byte 1023 times
 set textwrite,(iy+new_grf_flgs)	; print text to _plotSScreen

 xor a					; need to clear variables
 ld (Player1Score),a	; Player1Score = 0
 ld (Player2Score),a	; Player2Score = 0
 ld (FrameByte),a		; FrameByte = 0
 ld a,12				; start player 1 near top
 ld (Player1L),a		; Player1L = 12 
 ld a,44				; start player 2 near bottom
 ld (Player2L),a		; Player2L = 44
 ld a,$80				; need to set shots to inactive
 ld (Player1Shot),a		; Player1Shot = $80
 ld (Player2Shot),a		; Player2Shot = $80
 call PrintScores		; show scores the first time 

MainLoop:
 xor a					; default that nothing happened
 ld (FrameByte),a		; clear frame send byte

ErasePlayers:
 ld b,0					; player 1 is on left side
 ld a,(Player1L)		; get player 1's y coord
 ld c,a					; save it for draw
 ld hl,BlankSpr			; point to blank sprite
 call PutSprite			; erase the sprite
 ld b,120				; player 2 is on right side
 ld a,(Player2L)		; get player 2's y coord
 ld c,a					; save it for draw
 ld hl,BlankSpr			; point to blank sprite
 call PutSprite			; erase the sprite

WhichPlayer:
 ld a,(OurNum)			; find out which player we are
 or a					; player 1?
 jr nz,WhichPlayer2		; if not, we're player 2 
 ld hl,Player1L			; point to location for player 1
 jr CheckKeys			; check the keys
WhichPlayer2:
 ld hl,Player2L			; point to location for player 2 [fall through]

CheckKeys:
 halt					; wait for the interrupt
 ld a,%01111110			; check arrow keys
 out (1),a				; send mask to the key port
 nop \ nop				; wait for the port
 in a,(1)				; read mask from the port
 bit 3,a				; did they press up?
 jr z,UpHit				; then move the player up
 bit 0,a				; then did they press down?
 jr nz,CheckFire		; if not, don't move down [else fall through]

DownHit:
 ld a,(hl)				; get our location (remember, hl points to the correct data)
 cp 56					; already at the bottom?
 jr z,CheckFire			; check for fire
 inc (hl)				; move us down
 inc (hl)				; one more pixel
 ld a,2					; we just moved down
 ld (FrameByte),a		; update frame byte
 jr UpdatePlayer		; don't check for fire (multiple stuff gets complicated) 

UpHit:
 ld a,(hl)				; get our location
 cp 8					; at the top?
 jr z,CheckFire			; check for fire
 dec (hl)				; move us up
 dec (hl)				; one more pixel
 ld a,1					; we just moved up
 ld (FrameByte),a		; update frame byte
 jr UpdatePlayer		; don't check for fire

CheckFire:
 call _getky			; check for keys
 cp K_EXIT				; did they press exit?
 jp z,QuitEarly			; need to tell the other calc
 cp K_SECOND			; did they press 2nd?
 jr nz,UpdatePlayer		; if not, we're done here
 ld a,(OurNum)			; find out which player we are
 or a					; player 1?
 jr nz,FireBullet2		; if not, we're player 2 [fall through]

FireBullet1:
 ld hl,Player1Shot		; point to shot data
 ld a,$80				; need to see if it's inactive
 cp (hl)				; active?
 jr nz,UpdatePlayer		; if so, can't fire
 ld a,3					; we just fired
 ld (FrameByte),a		; update frame byte
 call Fire1				; fire bullet 1
 jr UpdatePlayer		; don't want to fire the other guy's gun
 
FireBullet2:
 ld hl,Player2Shot		; point to shot data
 ld a,$80				; need to see if it's inactive
 cp (hl)				; active?
 jr nz,UpdatePlayer		; if so, can't fire
 ld a,3					; we just fired
 ld (FrameByte),a		; update frame byte
 call Fire2				; fire bullet 2 [fall through]

UpdatePlayer:
 halt					; wait for other calc
 halt					; ...
 call ReceiveByte		; get a byte
 or a					; did we get one?
 jr z,UpdatePlayerSend	; if not, send ours
 cp 1					; is it 'move up'?
 jr z,UpdatePlayer1		; then move them up
 cp 2					; is it 'move down'?
 jr z,UpdatePlayer2		; then move them down
 cp 3					; is it 'fire'?
 jr z,UpdatePlayer3		; then make them fire
 cp 4					; is it 'quit'?
 jr z,UpdatePlayer4		; then let them quit
 jr UpdatePlayerSend	; shouldn't be here, but in case we are...
 
UpdatePlayer1:
 call WhichPlayerE		; find out which player they are
 dec (hl)				; move them up
 dec (hl)				; one more pixel
 jr UpdatePlayerSend	; we're done

UpdatePlayer2:
 call WhichPlayerE		; find out which player they are
 inc (hl)				; move them down
 inc (hl)				; one more pixel
 jr UpdatePlayerSend	; we're done

UpdatePlayer3:
 ld a,(OurNum)			; get our number
 or a					; are we player 1?
 jr nz,UpdatePlayer3O	; then skip player 2
 call Fire2				; fire bullet 2
 jr UpdatePlayerSend	; done here
UpdatePlayer3O:
 call Fire1				; fire bullet 1
 jr UpdatePlayerSend	; done here
 
UpdatePlayer4:
 xor a					; need to set OurNum to 0
 ld (OurNum),a			; make us 0 so we win
 jp Winner1				; we win (haha, they quit)
 
UpdatePlayerSend:
 ld a,(FrameByte)		; get byte to send
 or a					; is it 0?
 jr z,UpdateBullets		; then we don't need to send it
 call SendByte			; send the byte

UpdateBullets:
 ld bc,(Player1Shot)	; load player's bullet data
 ld a,$80				; need to check if it's active
 cp c					; is it inactive?
 jr z,UpdateBullets2	; then skip it
 ld hl,BlankSpr			; point to blank sprite
 call PutSprite			; erase it
 ld hl,Player1Shot+1	; point to shot's x coord
 ld a,(hl)				; get bullet coord
 add a,5				; move it
 ld (hl),a				; save coord
 ld a,127				; check with screen bounds
 cp (hl)				; is it off the screen?
 jr c,UpdateBulletsK1	; then kill it
 ld a,120				; check if kill is possible
 cp (hl)				; in the kill zone?
 jr nc,UpdateBulletsD1	; if not, checking is done
 ld a,(Player2L)		; get player's y coord
 sub 3					; even out the collision a bit
 dec hl					; move back to y coord
 sub (hl)				; compute distance
 cp -8					; is it less than 8?
 jr c,UpdateBulletsD1	; if not, no hit
 ld (hl),$80			; make it inactive
 ld hl,Player1Score		; point to player's score
 inc (hl)				; increase score
 ld a,10				; we play to 10
 cp (hl)				; are we at 10 points yet?
 jp z,Winner1			; then we have a winner!
 call PrintScores		; reprint scores 
 jr UpdateBullets2		; done here
UpdateBulletsD1:
 ld bc,(Player1Shot)	; load coords for draw
 ld hl,Bullet1Spr		; point to sprite
 call PutSprite			; draw it
 jr UpdateBullets2		; don't want to kill it
UpdateBulletsK1:
 dec hl					; move back to y coord
 ld (hl),$80			; mark it as inactive [fall through]

UpdateBullets2:
 ld bc,(Player2Shot)	; load player's bullet data
 ld a,$80				; need to check if it's active
 cp c					; is it inactive?
 jr z,RedrawPlayers		; then skip it
 ld hl,BlankSpr			; point to blank sprite
 call PutSprite			; erase it
 ld hl,Player2Shot+1	; point to shot's x coord
 ld a,(hl)				; get bullet coord
 sub 5					; move it
 ld (hl),a				; save coord
 ld a,127				; check with screen bounds
 cp (hl)				; is it off the screen?
 jr c,UpdateBulletsK2	; then kill it
 ld a,8					; check if kill is possible
 cp (hl)				; in the kill zone?
 jr c,UpdateBulletsD2	; if not, checking is done
 ld a,(Player1L)		; get player's y coord
 sub 3					; even out the collision a bit
 dec hl					; move back to y coord
 sub (hl)				; compute distance
 cp -8					; is it less than 8?
 jr c,UpdateBulletsD2	; if not, no hit
 ld (hl),$80			; make it inactive
 ld hl,Player2Score		; point to player's score
 inc (hl)				; increase score
 ld a,10				; we play to 10
 cp (hl)				; are we at 10 points yet?
 jp z,Winner2			; then we have a winner!
 call PrintScores		; reprint scores 
 jr RedrawPlayers		; done here
UpdateBulletsD2:
 ld bc,(Player2Shot)	; load coords for draw
 ld hl,Bullet2Spr		; point to sprite
 call PutSprite			; draw it
 jr RedrawPlayers		; don't want to kill it
UpdateBulletsK2:
 dec hl					; move back to y coord
 ld (hl),$80			; mark it as inactive [fall through]

RedrawPlayers:
 ld b,0					; player 1 is on left side
 ld a,(Player1L)		; get player 1's y coord
 ld c,a					; save it for draw
 ld hl,Player1Spr		; point to player 1's sprite
 call PutSprite			; draw the sprite
 ld b,120				; player 2 is on right side
 ld a,(Player2L)		; get player 2's y coord
 ld c,a					; save it for draw
 ld hl,Player2Spr		; point to player 2's sprite
 call PutSprite			; draw the sprite


DumpVirtScr:
 ld hl,VirtScr			; point to the virtual screen
 ld de,$fc00			; point to video memory
 ld bc,1024				; copy all 1024 bytes
 ldir					; dump the virtual screen to video ram


MainLoopEnd:
 jp MainLoop			; continue the main loop

QuitEarly:
 ld a,4					; the other calc needs to know we quit
 call SendByte			; send them the info
 jp Menu				; back to the menu
 
PrintScores:
 ld hl,$0020			; middle left
 ld (_penCol),hl		; set text location 
 ld a,(Player1Score)	; load the score
 add a,'0'				; turn it into a number
 call _vputmap			; print it
 ld hl,$0060			; middle right
 ld (_penCol),hl		; set text location
 ld a,(Player2Score)	; load the score
 add a,'0'				; turn it into a number
 call _vputmap			; print it
 ret					; we're done

Winner1:
 ld a,(OurNum)			; find out which player we are
 or a					; are we the winner?
WinnerJ:
 jr nz,Winner1L			; if not, we are the loser
 ld hl,YouWinText		; "You win!"
 jr WinnerShow			; show the text
Winner1L:
 ld hl,YouLoseText		; "You lost!" [fall through]
WinnerShow:
 ld de,$0603					; print at (4, 7)
 ld (_curRow),de				; set text position
 set textInverse,(iy+textflags)	; reverse text
 call _puts						; now print the text
 res textInverse,(iy+textflags)	; back to normal
WinnerLoop:
 call _getky					; read keypress
 jr z,WinnerLoop				; loop until one is pressed
 jp Menu						; go back to the menu
Winner2:
 ld a,(OurNum)			; find out which player we are
 dec a					; are we the winner?
 jr WinnerJ				; Winner1 code is exactly the same...

Fire1:
 ld a,(Player1L)		; get player's y coord
 add a,2				; move it down 2 pixels
 ld hl,Player1Shot		; point to shot data
 ld (hl),a				; load it with the player's y coord
 inc hl					; move to next byte
 ld (hl),8				; start the x coord
 ret					; done here

Fire2:
 ld a,(Player2L)		; get player's y coord
 add a,2				; move it down 2 pixels
 ld hl,Player2Shot		; point to shot data
 ld (hl),a				; load it with the player's y coord
 inc hl					; move to next byte
 ld (hl),116			; start the x coord
 ret					; done here

WhichPlayerE:
 ld a,(OurNum)			; find out which player they are
 or a					; player 2?
 jr nz,WhichPlayerE2	; if not, they're player 1
 ld hl,Player2L			; point to location for player 2
 ret					; we're done
WhichPlayerE2:
 ld hl,Player1L			; point to location for player 1
 ret					; we're done


WaitingText:
 .db "waiting...",0

YouWinText:
 .db "You win!",0

YouLoseText:
 .db "You lose!",0

MenuTable:
 .db 3
 .db " Outlaw v1.0 by David Phillips",0
 .db "Play",0
 .db "Help",0
 .db "Quit",0
 .dw StartGame
 .dw ShowHelp
 .dw Quit

HelpText:
;    "123456789012345678901"
 .db $ed,0						; must start like this
 .db "Outlaw v1.0",0
 .db "18 Nov 98",0
 .db " ",0
 .db "by David Phillips",0
 .db "<electrum@tfs.net>",0
 .db " ",0						; a blank line
 .db "Connect 2 TI-86's",0
 .db "together to play.",0
 .db "This is just a demo,",0
 .db "so the first player",0
 .db "to 10 points wins.",0
 .db "The 86 needs more",0
 .db "link games...",0
 .db " ",0
 .db "Controls:",0
 .db " -arrows = move guy",0
 .db " -2nd = shoot pistol",0
 .db " ",0
 .db "Enjoy!",0
 .db $ed						; must end like this

Player1Spr:
	.db %01010100
	.db %01111100
	.db %00010000
	.db %00111111
	.db %01010010
	.db %00111000
	.db %00101000
	.db %01101100

Player2Spr:
	.db %00101010
	.db %00111110
	.db %00001000
	.db %11111100
	.db %01001010
	.db %00011100
	.db %00010100
	.db %00110110

Bullet1Spr:
	.db %11100000
	.db %11110000
	.db %11100000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000

Bullet2Spr:
	.db %01110000
	.db %11110000
	.db %01110000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000

BlankSpr:
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000
	.db %00000000

TitlePic:
; compressed picture made with RLE2PIC
; RLE2PIC by David Phillips <electrum@tfs.net>


 .db $91,$00,$30,$1f,$91,$ff,$0e,$f0,$10,$91,$00,$0e
 .db $18,$10,$91,$00,$0e,$18,$10,$91,$00,$0e,$18,$10
 .db $07,$fc,$91,$00,$03,$70,$00,$1f,$80,$91,$00,$05
 .db $18,$10,$07,$fc,$91,$00,$03,$70,$00,$1f,$80,$91
 .db $00,$05,$18,$10,$38,$03,$80,$00,$00,$70,$00,$03
 .db $80,$91,$00,$05,$18,$10,$38,$03,$80,$00,$00,$70
 .db $00,$03,$80,$91,$00,$05,$18,$10,$38,$03,$8e,$00
 .db $e3,$fe,$00,$03,$80,$07,$fc,$0e,$00,$e0,$18,$10
 .db $38,$03,$8e,$00,$e3,$fe,$00,$03,$80,$07,$fc,$0e
 .db $00,$e0,$18,$10,$38,$03,$8e,$00,$e0,$70,$00,$03
 .db $80,$00,$03,$8e,$00,$e0,$18,$10,$38,$03,$8e,$00
 .db $e0,$70,$00,$03,$80,$00,$03,$8e,$00,$e0,$18,$10
 .db $38,$03,$8e,$00,$e0,$70,$00,$03,$80,$07,$ff,$8e
 .db $38,$e0,$18,$10,$38,$03,$8e,$00,$e0,$70,$00,$03
 .db $80,$07,$ff,$8e,$38,$e0,$18,$10,$38,$03,$8e,$07
 .db $e0,$70,$38,$03,$80,$38,$03,$8e,$38,$e0,$18,$10
 .db $38,$03,$8e,$07,$e0,$70,$38,$03,$80,$38,$03,$8e
 .db $38,$e0,$18,$10,$07,$fc,$01,$f8,$e0,$0f,$c0,$1f
 .db $f0,$07,$ff,$81,$c7,$00,$18,$10,$07,$fc,$01,$f8
 .db $e0,$0f,$c0,$1f,$f0,$07,$ff,$81,$c7,$00,$18,$10
 .db $91,$00,$0e,$18,$10,$91,$00,$0e,$18,$10,$91,$00
 .db $0e,$18,$10,$91,$00,$0e,$18,$10,$91,$00,$0e,$18
 .db $10,$91,$00,$0e,$18,$10,$91,$00,$0e,$18,$10,$91
 .db $00,$0e,$18,$10,$91,$00,$0e,$18,$10,$91,$00,$0e
 .db $18,$10,$91,$00,$06,$f8,$91,$00,$03,$fc,$91,$00
 .db $03,$18,$10,$91,$00,$04,$10,$01,$06,$00,$00,$11
 .db $0a,$20,$28,$00,$18,$10,$00,$02,$48,$00,$10,$02
 .db $19,$00,$04,$12,$09,$21,$54,$00,$18,$10,$00,$02
 .db $48,$00,$10,$02,$11,$00,$04,$22,$11,$41,$54,$00
 .db $18,$10,$00,$00,$90,$00,$20,$02,$11,$00,$00,$22
 .db $11,$40,$50,$00,$18,$10,$7f,$55,$fb,$ac,$3d,$a1
 .db $a1,$39,$e9,$c1,$92,$b2,$ad,$d8,$18,$10,$29,$64
 .db $94,$b4,$25,$20,$21,$48,$aa,$40,$3c,$d2,$aa,$50
 .db $18,$10,$49,$49,$27,$28,$45,$40,$22,$79,$34,$40
 .db $20,$95,$54,$48,$18,$10,$52,$89,$24,$48,$4a,$40
 .db $44,$91,$91,$01,$54,$80,$61,$25,$54,$a8,$18,$10
 .db $7c,$89,$27,$c8,$73,$c0,$78,$f9,$97,$40,$41,$45
 .db $57,$30,$18,$10,$91,$00,$05,$40,$91,$00,$06,$08
 .db $00,$18,$10,$91,$00,$04,$04,$40,$91,$00,$06,$08
 .db $00,$18,$10,$91,$00,$04,$03,$80,$91,$00,$06,$10
 .db $00,$18,$10,$91,$00,$0e,$18,$10,$91,$00,$0e,$18
 .db $10,$91,$00,$0e,$18,$10,$91,$00,$0e,$18,$10,$91
 .db $00,$0e,$18,$11,$d8,$00,$18,$80,$00,$80,$71,$9c
 .db $e0,$39,$80,$00,$08,$02,$18,$11,$cc,$60,$18,$e6
 .db $01,$00,$12,$14,$a0,$48,$8c,$21,$10,$42,$18,$10
 .db $8a,$90,$14,$81,$38,$80,$13,$94,$a0,$40,$82,$52
 .db $88,$a2,$18,$10,$8a,$e0,$1c,$87,$20,$80,$62,$94
 .db $a0,$40,$8e,$31,$88,$80,$18,$11,$da,$70,$36,$e7
 .db $39,$c0,$73,$9c,$e0,$39,$ce,$73,$9c,$e2,$18,$10
 .db $91,$00,$0e,$18,$10,$91,$00,$0e,$18,$10,$91,$00
 .db $0e,$18,$10,$91,$00,$0e,$18,$1f,$91,$ff,$0e,$f8
 .db $07,$91,$ff,$0e,$f8,$91,$00,$40

; 1024 bytes compressed to 620 -- 60% of original.

#include "ascr.asm"			; These are all of the routines used by this demo/game
#include "menu.asm"			; You are free to use these under the condition that you
#include "rle.asm"			; leave the headers in (so other people can understand them)
#include "textview.asm"		; and that you distribute your source code (so they can learn)
#include "link86.asm"		; Believe it or not, it takes a while to write this stuff!

.end
